"""
本作品采用知识共享署名-非商业性使用-相同方式共享 4.0 国际许可协议进行许可。
当您使用本作品相关图纸或源码等资料时，视为您同意并遵循此协议内容。

项目开源地址：https://www.laserblock.cn/thread-23573-1-1.html

作者：李嘉泳
邮箱：17620745509@126.COM
BiliBili：https://space.bilibili.com/106497171

Laserblock开源社区：https://www.laserblock.cn/
"""
"""
请仅在此文件中更改写字机参数，如果您不清楚程序中未在这里列出的参数的作用，请勿随意更改程序！
请仅更改数值或双引号中的文本，请勿改变其它符号（如逗号、冒号、引号、括号等）的位置！
"""
print("IMPORTING CONFIG")
cfg = {
    # -----机械参数---
    "core": {
        # 摆臂舵机参数调节
        "arm_servo": {  # 摆臂舵机参数调节
            "max_angel": 120,  # 最大角度，即打印字体最下方水平线在纸张的位置，增大该参数字体底部水平线下移，单位：度
            "min_angel": 70,  # 最小角度，即打印字体最上方水平线在纸张的位置，增大该参数字体顶部水平线下移，单位：度
            "delay": 15,  # 步进延时，设置越小打印速度越快，请根据舵机实际响应速度调节，单位：毫秒
            "dead_zone": 5,  # 死区补偿，在舵机反向移动时额外移动此角度补偿机械装配误差导致的死区误差，单位：度
            "dead_zone_delay": 20,  # 死区补偿进延时，设置越小打印速度越快，请根据舵机实际响应速度调节，单位：毫秒
            "dead_zone_reset_delay": 20,  # 死区复位补偿进延时，设置越小打印速度越快，请根据舵机实际响应速度调节，单位：毫秒
            "angel_fix": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        },
        # 打点舵机参数调节
        "dot_servo": {
            "up_angel": 80,  # 抬升角度，请设置合理角度使打点粗细均匀合适，单位：度
            "down_angel": 68,  # 下落角度，请设置合理角度使舵机下落时纸张不会触碰到笔头，单位：度
            "up_delay": 80,  # 抬升延时，设置越小打印速度越快，请根据舵机实际响应速度调节，单位：毫秒
            "down_delay": 80,  # 下落延时，设置越小打印速度越快，请根据舵机实际响应速度调节，单位：毫秒
            "angel_fix": 1,  # 角度补偿，补偿因装配问题导致的平台倾斜，设置正参数补偿上深下浅的倾斜，设置负参数补偿上浅下深的倾斜，设置参数越大补偿角度越高，单位：度
            "standby_angel": 68,  # 待机角度，请设置至不卡住舵机运动前提下的最低值，单位：度
            "standby_delay": 0,  # 待机角度运动延时，设置越小打印速度越快，请根据舵机实际响应速度调节，单位：毫秒
        },
        # 步进电机参数调节
        "stepper": {
            "step_pwm": 120,  # 设置每步发送PWM的个数，设置越高步距越大
            "delay": 1,  # 步进延时，设置越小步进电机移动速度越快，请根据步进电机实际响应速度调节，单位：毫秒
        },
        # 双向打印参数调节(Alpha)
        "bidirectional_print": {
            "enable": False,  # 启用双向打印，默认不启用，核心代码未完成双向打印适配
            "angel_fix": 2,  # 双向打印反向打印时的角度补偿，单位：度
        },
        # 目录设置
        "path": {"bin_file_path": "/bin/"},  # 写字机中BIN文件存放目录
    },
    # -----硬件设置-----
    "hardware": {
        "arm_servo_pin": 1,  # 设置摆臂舵机管脚
        "dot_servo_pin": 0,  # 设置打点舵机管脚
        "stepper_pin_1": 13,  # 设置步进电机1号管脚
        "stepper_pin_2": 14,  # 设置步进电机2号管脚
        "stepper_pin_3": 15,  # 设置步进电机3号管脚
        "stepper_pin_4": 16,  # 设置步进电机4号管脚
    },
    # -----屏幕设置-----
    "screen": {
        "enable_screen_saver": True,  # 设置是否启用屏保功能
        "saver_time": 20,  # 设置屏保时间，单位：秒
        "off_time": 0,  # 设置熄屏时间，单位：秒
    },
    # -----触摸键设置-----
    "touchpad": {"trigger_value": 300},
    # -----网络设置-----
    "network": {
        "name": "YOUR-SSID",  # 网络WiFi名称
        "password": "YOUR-SSPW",  # 网络WiFi密码
        "host": "192.168.1.233",  # 主机IP地址
        "port": "2333",  # 端口号
        "status_file_name": "stats.mps",  # 状态指令文件名
        "fresh_time": 3000,  # 刷新指令间隔，单位：毫秒
        "direct_print": False,  # 下载文件完成后是否直接开始打印
        "startup_connect": False,  # 设置是否开机自动连接WiFi
    },
}
