"""
本作品采用知识共享署名-非商业性使用-相同方式共享 4.0 国际许可协议进行许可。
当您使用本作品相关图纸或源码等资料时，视为您同意并遵循此协议内容。

项目开源地址：https://www.laserblock.cn/thread-23573-1-1.html

作者：李嘉泳
邮箱：17620745509@126.COM
BiliBili：https://space.bilibili.com/106497171

Laserblock开源社区：https://www.laserblock.cn/
"""
print("IMPORTING CORE")
# mPythonType:0
from mpython import *
from servo import Servo
import printer_global_variable as glovar
import printer_gui_menu as menu
import printer_dot_servo as dot
import printer_gui as gui
import printer_stepper as stepper
import printer_file_system as file
import os
import math
import utime  # ---GUI---
import printer_screen_saver as saver
import printer_input as inpt
import config as cfg

servo = Servo(1, min_us=500, max_us=2500, actuation_range=180)
servo.write_angle(glovar.ARM_MIN_ANGEL)


def arm_move_to_step(step, delay=True, dead_zone_fix=False):
    if step < 0 or step > 15:
        print("错误：指定步数超出范围：", step)
        return
    # print('arm move to step:',step)
    if not dead_zone_fix:
        servo.write_angle(glovar.arm_steps_angel[step])
        # print('arm servo angle:',glovar.arm_steps_angel[step])
    else:
        servo.write_angle(glovar.arm_steps_angel[step] - glovar.ARM_DEAD_ZONE)
        # print('arm servo angle:',glovar.arm_steps_angel[step] - glovar.ARM_DEAD_ZONE)
    servo_move_steps = glovar.current_arm_at_step - step
    if servo_move_steps < 0:
        servo_move_steps *= -1
    if delay:
        time.sleep_ms(glovar.ARM_STEP_DELAY * servo_move_steps)
    glovar.current_arm_at_step = step


def bin_fill_str(str):
    str = str[2:]
    for i in range(8 - len(str)):
        str = "0" + str
    return str


def get_col_bin_str(col):
    this_col_bin_str = ""
    for this_row in range(glovar.hex_data_height):
        this_col_bin_str += glovar.bin_data_buffer_array[this_row][col]
    return this_col_bin_str


def init_hex_file(file_name):
    if glovar.last_print_filepath == file_name:
        print("文件已有缓存")
        return
    glovar.last_print_filepath = file_name
    glovar.hex_data_size = os.stat(file_name)[6]
    print("文件大小：" + str(glovar.hex_data_size) + "byte")
    print("正在缓存文件")
    glovar.hex_data_buffer = file.get_byte_from_file(file_name)
    already_buffered_data_size = len(glovar.hex_data_buffer)
    print("缓存大小：" + str(already_buffered_data_size) + "byte")
    if not glovar.hex_data_size == already_buffered_data_size:
        print("错误：缓存大小不一致")
        return 1
    glovar.hex_data_height_byte = int(glovar.hex_data_height / 8)
    print(
        "HEX图像默认高：" + str(glovar.hex_data_height),
        "bit , " + str(glovar.hex_data_height_byte) + "byte",
    )
    glovar.hex_data_width = int(((glovar.hex_data_size * 8) / glovar.hex_data_height))
    glovar.hex_data_width_byte = int(glovar.hex_data_width / 8)
    print(
        "HEX图像宽：" + str(glovar.hex_data_width),
        "bit , " + str(glovar.hex_data_width_byte) + "byte",
    )
    current_col_number = 0
    current_row_number = 0
    this_row_bin_buffer = ""
    gui_processd_byte = 0  # ---GUI---
    gui_display_percent = 0  # ---GUI---
    for this_byte_int in glovar.hex_data_buffer:
        this_byte_bin_buffer = ""
        this_byte_bin_buffer = bin_fill_str(str(bin(this_byte_int)))
        this_row_bin_buffer += this_byte_bin_buffer
        current_col_number += 1
        if current_col_number == glovar.hex_data_width_byte:
            glovar.bin_data_buffer_array[current_row_number] = this_row_bin_buffer
            this_row_bin_buffer = ""
            current_col_number = 0
            current_row_number += 1
        gui_processd_byte += 1  # ---GUI---
        if not gui_display_percent == round(
            gui_processd_byte / glovar.hex_data_size * 100
        ):  # ---GUI---
            gui.screen_fresh_percent(
                round(gui_processd_byte / glovar.hex_data_size * 100)
            )  # ---GUI---
            gui_display_percent = round(
                gui_processd_byte / glovar.hex_data_size * 100
            )  # ---GUI---


def print_col(col_str):
    dot.set_dot(False)
    for glovar.current_print_progress_row in range(len(col_str)):
        handle_pause()
        if col_str[glovar.current_print_progress_row] == "0":
            continue
        arm_move_to_step(glovar.current_print_progress_row)
        dot.dot_once()
    dot.dot_standby()
    return


def prepare_col(col_str):
    for prepare_row in range(len(col_str)):
        if (
            col_str[prepare_row] == "1"
            and not glovar.current_arm_at_step == prepare_row
        ):
            arm_move_to_step(prepare_row, delay=False, dead_zone_fix=True)
            return


def init_hardware_data():
    print("正在初始化硬件数据")
    glovar.arm_steps = (glovar.ARM_MAX_ANGEL - glovar.ARM_MIN_ANGEL) / (
        glovar.hex_data_height - 1
    )
    dot.steps = dot.ANGEL_FIX / (glovar.hex_data_height - 1)
    print("摆臂舵机步距角度：" + str(glovar.arm_steps))
    print("打点舵机步距角度：" + str(dot.steps))
    for check_precision_number in range(glovar.hex_data_height):
        glovar.arm_steps_angel[check_precision_number] = (
            round(glovar.ARM_MIN_ANGEL + check_precision_number * glovar.arm_steps)
        ) + cfg.cfg["core"]["arm_servo"]["angel_fix"][check_precision_number]
    print("摆臂舵机步数角度转换数组：")
    print(glovar.arm_steps_angel)


def print_hex_file(file_path):
    if not gui.print_content_confirm(file_path):
        return
    print("开始打印文件:", file_path)
    oled.fill(0)  # ---GUI---
    gui.auto_show_text(1, "正 在 解 析")  # ---GUI---
    oled.show()  # ---GUI---
    if init_hex_file(file_path):
        print("解析数据时发生错误，打印完成")
        return 1
    init_hardware_data()
    oled.fill(0)  # ---GUI---
    gui.auto_show_text(1, "正  在  打  印")  # ---GUI---
    gui.screen_fresh_percent(0)  # ---GUI---
    glovar.print_start_time = utime.ticks_ms()  # ---GUI---
    oled.show()  # ---GUI---
    """
    打印核心
    """
    for current_printing_col in range(glovar.hex_data_width):
        time.sleep_ms(glovar.ARM_DEAD_ZONE_DELAY)
        servo.write_angle(glovar.arm_steps_angel[glovar.current_arm_at_step])
        time.sleep_ms(glovar.ARM_DEAD_ZONE_RESET_DELAY)
        gui.screen_fresh_percent(
            current_printing_col / glovar.hex_data_width * 100
        )  # ---GUI---
        print_col(get_col_bin_str(current_printing_col))
        if not current_printing_col == glovar.hex_data_width - 1:
            prepare_col(get_col_bin_str(current_printing_col + 1))
        stepper.steps(glovar.STEPPER_STEPS)
    """
    打印核心结束
    """
    glovar.print_finish_time = utime.ticks_ms()  # ---GUI---
    print("打印完成")
    oled.fill(0)  # ---GUI---
    gui.auto_show_text(1, "打  印  完  成")  # ---GUI---
    print_time_second = round(
        (glovar.print_finish_time - glovar.print_start_time) / 1000
    )
    print(
        "耗时：",
        gui.convert_time(print_time_second)[1],
        "分",
        gui.convert_time(print_time_second)[2],
        "秒",
    )
    gui.auto_show_text(
        2,
        "耗时："
        + str(gui.convert_time(print_time_second)[1])
        + "分"
        + str(gui.convert_time(print_time_second)[2])
        + "秒",
    )  # ---GUI---
    dot.servo.write_angle(dot.STANDBY_ANGEL)
    servo.write_angle(glovar.ARM_MIN_ANGEL)
    stepper.steps(glovar.print_finish_tab)
    saver.reset()  # ---GUI---


def handle_pause():  # ---GUI---
    if inpt.is_pressed(inpt.b):
        oled.fill(0)
        gui.auto_show_text(1, "任务已暂停")
        # gui.auto_show_text(2, '确认取消吗')
        while True:
            if inpt.is_pressed_short(inpt.b):
                oled.fill(0)
                gui.auto_show_text(1, "正  在  打  印")  # ---GUI---
                return
            time.sleep_ms(glovar.general_sleep_time)
