"""
本作品采用知识共享署名-非商业性使用-相同方式共享 4.0 国际许可协议进行许可。
当您使用本作品相关图纸或源码等资料时，视为您同意并遵循此协议内容。

项目开源地址：https://www.laserblock.cn/thread-23573-1-1.html

作者：李嘉泳
邮箱：17620745509@126.COM
BiliBili：https://space.bilibili.com/106497171

Laserblock开源社区：https://www.laserblock.cn/
"""
print("IMPORTING NETWORK")

from mpython import *
import urequests
import ujson
import config as cfg
import network
import utime
import os
import printer_gui as gui
import time
import printer_global_variable as glovar
import printer_core as core

seed = -1
status_file_url = ""
next_tick_time = 0
host_address = ""


def init():
    global status_file_url, host_address
    gui.auto_show_text(1, "正 在 连 接")
    gui.screen_fresh_percent(0)
    print("正在解析配置文件")
    my_wifi = network.WLAN(network.STA_IF)
    """
    if my_wifi.isconnected():
        glovar.network_enabled = True
        gui.screen_fresh_percent(99)
        print("WiFi已经连接")
        return
    """
    print("初始化Wi-Fi")
    gui.screen_fresh_percent(25)
    print("正在连接SSID：", cfg.cfg["network"]["name"])
    try:
        my_wifi.active(True)
        my_wifi.connect(cfg.cfg["network"]["name"], cfg.cfg["network"]["password"])
        loop_times = 0
        while not my_wifi.isconnected():
            if loop_times == 10:
                print("正在重试...")
                my_wifi.connect(
                    cfg.cfg["network"]["name"], cfg.cfg["network"]["password"]
                )
            if loop_times == 20:
                glovar.network_enabled = False
                print("错误：无法连接WiFi")
                oled.fill(0)
                gui.auto_show_text(1, "连 接 失 败")
                gui.auto_show_text(2, "WiFi连接失败")
                time.sleep(5)
                return
            loop_times += 1
            time.sleep(0.5)
    except:
        glovar.network_enabled = False
        print("错误：无法连接WiFi")
        oled.fill(0)
        gui.auto_show_text(1, "连 接 失 败")
        gui.auto_show_text(2, "WiFi连接失败")
        time.sleep(5)
        return
    gui.screen_fresh_percent(50)
    host_address = (
        "http://" + cfg.cfg["network"]["host"] + ":" + cfg.cfg["network"]["port"] + "/"
    )
    status_file_url = host_address + cfg.cfg["network"]["status_file_name"]
    print("状态信息文件路径：", status_file_url)
    gui.screen_fresh_percent(75)
    try:
        urequests.get(status_file_url)
    except:
        print("错误：获取状态信息文件失败！")
        oled.fill(0)
        gui.auto_show_text(1, "连 接 失 败")
        gui.auto_show_text(2, "无法获取状态")
        time.sleep(5)
        return
    print("WiFi连接成功")
    gui.screen_fresh_percent(99)


def download_files(path, file_name):
    oled.fill(0)
    gui.auto_show_text(1, "正 在 下 载")
    gui.screen_fresh_percent(0)
    print("正在下载文件，文件名：", file_name, "，路径：", path)
    print("正在初始化下载")
    bin_file = open(path + file_name, "wb")
    gui.screen_fresh_percent(25)
    print("正在下载...")
    network_bin_file = urequests.get(host_address + file_name)
    gui.screen_fresh_percent(50)
    bin_file.write(network_bin_file.content)
    gui.screen_fresh_percent(75)
    bin_file.close()
    gui.screen_fresh_percent(99)
    print(
        "下载完成！文件大小：",
        os.stat(path + file_name)[6],
        "byte",
    )


def update():
    global status_file_url, seed, next_tick_time
    if utime.ticks_ms() < next_tick_time:
        return
    next_tick_time = utime.ticks_ms() + cfg.cfg["network"]["fresh_time"]
    try:
        status_file = urequests.get(status_file_url)
    except:
        # print("错误：获取状态信息文件失败！")
        return False
    try:
        parsed_json = ujson.loads(status_file.content)
    except:
        print("错误：状态信息文件解析失败！")
        return False
    if seed == parsed_json["seed"]:
        return False
    print("获取到更新内容")
    seed = parsed_json["seed"]
    if parsed_json["status"] == "standby":
        return False
    if parsed_json["status"] == "delete":
        oled.fill(0)
        gui.auto_show_text(1, "正 在 删 除")
        gui.screen_fresh_percent(0)
        print("获取到删除指令，文件名：", parsed_json["filename"], "，路径：", parsed_json["path"])
        print("正在删除...")
        gui.screen_fresh_percent(50)
        os.chdir(parsed_json["path"])
        if parsed_json["filename"] == "*":
            for file_name in os.listdir():
                print("删除" + file_name)
                try:
                    os.remove(file_name)
                except:
                    print(parsed_json["filename"] + "删除失败！")
        else:
            print("删除" + parsed_json["filename"])
            try:
                os.remove(parsed_json["filename"])
            except:
                print(parsed_json["filename"] + "删除失败！")
        os.chdir("/")
        gui.screen_fresh_percent(99)
        return True
    if parsed_json["status"] == "download" or "print":
        if parsed_json["filename"][:1] == "[":
            print("获取到文件列表")
            file_name = parsed_json["filename"][1 : len(parsed_json["filename"]) - 1]
            file_array = file_name.split(",")
            for this_file in file_array:
                download_files(parsed_json["path"], this_file)
        else:
            download_files(parsed_json["path"], parsed_json["filename"])
        if parsed_json["status"] == "print":
            core.print_hex_file(parsed_json["path"] + parsed_json["filename"])
        return True
    return False
